<?php
namespace Ak\Woo\Model\Entity;

use Ak\Orm\Mapping\DiscriminatorEntry;
use Ak\Woo\Model\LineItemInterface;
use Ak\Woo\Model\OrderInterface;
use Ak\Wp\Model\Entity\Post;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

/**
 * Class ShopOrder
 *
 * @package Ak\Woo\Model\Entity
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/woo-model
 *
 * @ORM\Entity()
 * @DiscriminatorEntry("shop_order")
 */
class Order extends Post implements OrderInterface
{
    /**
     * @var LineItemInterface[]|Collection
     *
     * @ORM\OneToMany(targetEntity="Ak\Woo\Model\Entity\Order\LineItem", mappedBy="order")
     */
    protected $items;

    /**
     * Vraća ID korisnika koji je napravio narudžbu.
     *
     * @return int
     */
    public function getCustomerId(): int
    {
        return intval($this->getMeta('_customer_user'));
    }

    /**
     * Vraća šifru metode naplate kojom je ova narudžba plaćena.
     *
     * @return string
     */
    public function getPaymentMethod(): ?string
    {
        return $this->getMeta('_payment_method');
    }

    /**
     * Vraća stavke ove narudžbe.
     *
     * @return LineItemInterface[]|Collection
     */
    public function getItems(): Collection
    {
        return $this->items;
    }

    /**
     * Vraća ukupan iznos narudžbe.
     *
     * @return float
     */
    public function getTotal(): float
    {
        return floatval($this->getMeta('_order_total'));
    }
}